==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/es.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Encuesta de uso",
    "Last report sent on: {on}" : "Último informe enviado el {on}",
    "An error occurred while sending your report." : "Se ha producido un error al enviar tu informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de apps <em>(para cada app: nombre, versión, activa o inactiva)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Entorno de base de datos <em>(tipo, versión, tamaño de la base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información de cifrado <em>(¿está activado?, módulo por defecto)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de recursos compartidos <em>(por tipo y configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Entorno PHP <em>(versión, límite de memoria, tiempo de ejecución máximo, tamaño de archivo máximo)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles de la instancia del servidor <em>(versión, uso de memcache, estado del bloqueo de archivos/previsualizaciones/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estadísticas <em>(número de archivos, usuarios, almacenamientos por tipo, comentarios y etiquetas)</em>",
    "Help improve Nextcloud" : "Ayuda a mejorar Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "¿Quieres ayudarnos a mejorar Nextcloud aportando algunos datos anónimos sobre tu configuración y uso? Puedes desactivarlo en cualquier momento en la configuración de administrador.",
    "Not now" : "Ahora no",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envía datos anonimizados a Nextcloud para ayudarnos a mejorar NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envía datos anonimizados a Nextcloud para ayudarnos a mejorar. Tú\n          siempre tendrás el control completo del contenido enviado a Nextcloud y puedes desactivarlo\n           de nuevo en cualquier momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudar a mejorar Nextcloud enviándonos algunos datos sobre tu configuración y uso actuales.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Nos tomamos en serio tu privacidad. El envío de datos está desactivado por defecto y, si lo activas, primero se anonimizarán, y se te dará la opción de elegir qué quieres compartir. Al recibir un informe, el anterior es eliminado. Sube un informe en blanco para borrar todos los datos almacenados actualmente en el servidor.",
    "Send new report now" : "Enviar ahora un nuevo informe",
    "Send usage survey monthly" : "Enviar la encuesta de uso mensualmente",
    "Data to send" : "Datos que se enviarán",
    "Last report sent on: %s" : "Último informe enviado el %s",
    "Last report" : "Último informe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/es.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último informe enviado el {on}",
    "An error occurred while sending your report." : "Se ha producido un error al enviar tu informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de apps <em>(para cada app: nombre, versión, activa o inactiva)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Entorno de base de datos <em>(tipo, versión, tamaño de la base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información de cifrado <em>(¿está activado?, módulo por defecto)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de recursos compartidos <em>(por tipo y configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Entorno PHP <em>(versión, límite de memoria, tiempo de ejecución máximo, tamaño de archivo máximo)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles de la instancia del servidor <em>(versión, uso de memcache, estado del bloqueo de archivos/previsualizaciones/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estadísticas <em>(número de archivos, usuarios, tipos de almacenamientos, comentarios y etiquetas)</em>",
    "Usage survey" : "Encuesta de uso",
    "Help improve Nextcloud" : "Ayuda a mejorar Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "¿Quieres ayudarnos a mejorar Nextcloud aportando algunos datos anónimos sobre tu configuración y uso? Puedes desactivarlo en cualquier momento en la configuración de administrador.",
    "Not now" : "Ahora no",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envía datos anonimizados a Nextcloud para ayudarnos a mejorar NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Envía datos anonimizados a Nextcloud para ayudarnos a mejorar. Tú\n          siempre tendrás el control completo del contenido enviado a Nextcloud y puedes desactivarlo\n           de nuevo en cualquier momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudar a mejorar Nextcloud enviándonos algunos datos sobre tu configuración y uso actuales.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Nos tomamos en serio tu privacidad. El envío de datos está desactivado por defecto y, si lo activas, primero se anonimizarán, y se te dará la opción de elegir qué quieres compartir. Al recibir un informe, el anterior es eliminado. Sube un informe en blanco para borrar todos los datos almacenados actualmente en el servidor.",
    "Send new report now" : "Enviar ahora un nuevo informe",
    "Send usage survey monthly" : "Enviar la encuesta de uso mensualmente",
    "Data to send" : "Datos que se enviarán",
    "Last report sent on: %s" : "Último informe enviado el %s",
    "Last report" : "Último informe",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envía datos anonimizados a Nextcloud para ayudarnos a mejorar. Tú\n          siempre tendrás el control completo del contenido enviado a Nextcloud y puedes desactivarlo\n           de nuevo en cualquier momento."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
